@@ -10,8 +10,9 @@
 """Schemas for parameter parsing."""
 
 
-from invenio_records_resources.resources.records.args import \
-    SearchRequestArgsSchema as SearchRequestArgsSchemaBase
+from invenio_records_resources.resources.records.args import (
+    SearchRequestArgsSchema as SearchRequestArgsSchemaBase,
+)
 from marshmallow import fields
 
 
