@@ -7,8 +7,9 @@
 
 """Records service relations component."""
 
-from invenio_records_resources.services.records.components import \
-    RelationsComponent as RelationsComponentBase
+from invenio_records_resources.services.records.components import (
+    RelationsComponent as RelationsComponentBase,
+)
 
 
 class RelationsComponent(RelationsComponentBase):
